@@ -8,6 +8,7 @@ You can also send joint commands, compute forward or inverse kinematics.
 """
 
 import asyncio
+import atexit
 import threading
 import time
 from typing import List
@@ -62,7 +63,8 @@ class ReachySDK:
         self._fans: List[Fan] = []
         self._force_sensors: List[ForceSensor] = []
 
-        self._parts = ReachyParts
+        self._ready = threading.Event()
+        self._pushed_command = threading.Event()
 
         self._setup_joints()
         self._setup_arms()
@@ -79,6 +81,10 @@ class ReachySDK:
         self._sync_thread.daemon = True
         self._sync_thread.start()
 
+        _open_connection.append(self)
+
+        self._ready.wait()
+
     def __repr__(self) -> str:
         """Clean representation of a Reachy."""
         s = '\n\t'.join([str(j) for j in self._joints])
@@ -207,6 +213,8 @@ class ReachySDK:
 
                 commands = await self._poll_waiting_commands()
                 yield commands
+                self._pushed_command.set()
+                self._pushed_command.clear()
                 last_pub = time.time()
 
         await joint_stub.StreamJointsCommands(command_poll())
@@ -215,6 +223,8 @@ class ReachySDK:
         for joint in self._joints:
             joint._setup_sync_loop()
 
+        self._ready.set()
+
         async_channel = grpc.aio.insecure_channel(f'{self._host}:{self._sdk_port}')
         joint_stub = joint_pb2_grpc.JointServiceStub(async_channel)
 
@@ -226,7 +236,7 @@ class ReachySDK:
         )
 
     def _change_compliancy(self, part, compliant: bool):
-        if part not in [p.name.lower() for p in self._parts]:
+        if part not in [p.name.lower() for p in ReachyParts]:
             raise ValueError("Part to turn on/off should be either 'reachy', 'l_arm', 'r_arm' or 'head'.")
 
         if part == 'reachy':
@@ -252,3 +262,18 @@ class ReachySDK:
         Having part = 'reachy' corresponds to turning all avaible joints compliant.
         """
         self._change_compliancy(part, compliant=True)
+
+
+_open_connection: List[ReachySDK] = []
+
+
+def flush_communication():
+    """Flush communication before leaving.
+
+    We make sure all buffered commands have been sent before actually leaving.
+    """
+    for reachy in _open_connection:
+        reachy._pushed_command.wait(timeout=0.5)
+
+
+atexit.register(flush_communication)
